Learn R Programming

pollstR (version 1.4.0)

pollster_house_effects: House Effects

Description

For each chart, Pollster estimates house effects for each pollster, which is roughly the average difference between the polls of a pollster and the average of all the polls. This is not officially part of the Pollster API.

Usage

pollster_house_effects(slug)

Arguments

slug
The slug of the chart

Value

A data frame

Examples

Run this code
## Not run: 
#   pollster_house_effects("2016-general-election-trump-vs-clinton")
# ## End(Not run)

Run the code above in your browser using DataLab